Interface-mediated noble metal deposition on transition metal dichalcogenide nanostructures | Nature Chemistry
Author: Yifan Sun
Description: Functionalizing the surfaces of transition metal dichalcogenide (TMD) nanosheets with noble metals is important for electrically contacting them to devices, as well as improving their catalytic and sensing capabilities. Solution-phase deposition provides a scalable approach to the creation of metal–TMD hybrid systems, but controlling such processes remains challenging. Here we elucidate the different pathways by which gold and silver deposit at room temperature onto colloidal 1T-WS2, 2H-WS2, 2H-MoSe2, 2H-WSe2, 1T′-MoTe2 and Td-WTe2 few-layer nanostructures to produce several distinct classes of 0D–2D and 2D–2D metal–TMD hybrids. Uniform gold nanoparticles form on all of the TMDs. By contrast, silver deposits as nanoparticles with a bimodal size distribution on the disulfides and diselenides, and as atomically thin layers on the ditellurides. The various sizes and morphologies of these surface-bound metal species arise from the relative strengths of the interfacial metal–chalcogen bonds [cell cut: 1524 characters, first 1000 kept]
Keywords: Materials chemistry
Date: 2020-02-24

Skip to main content

Advertisement

Thank you for visiting nature.com. You are using a browser version with limited support for CSS. To obtain the best experience, we recommend you use a more up to date browser (or turn off compatibility mode in Internet Explorer). In the meantime, to ensure continued support, we are displaying the site without styles and JavaScript.

- Article
- Published: 24 February 2020

# Interface-mediated noble metal deposition on transition metal dichalcogenide nanostructures

- Yifan Sun ORCID: orcid.org/0000-0002-4082-53791,2,3,
- Yuanxi Wang ORCID: orcid.org/0000-0002-0659-11342,3,4,5,
- Jamie Y. C. Chen1,
- Kazunori Fujisawa2,3,4,
- Cameron F. Holder1,
- Jeffery T. Miller6,
- Vincent H. Crespi
  ORCID: orcid.org/0000-0003-3846-31931,2,3,4,5,7,
- Mauricio Terrones
  ORCID: orcid.org/0000-0003-0010-28511,2,3,4,7 &
- Raymond E. Schaak
  ORCID: orcid.org/0000-0002-7468-81811,2,8

Nature Chemistry volume 12, pages284–293(2020)Cite this article

- 8175 Accesses

- 8 Citations

- 42 Altmetric

- Metrics details

### Subjects

- Materials chemistry
- Nanoparticle synthesis
- Nanoscale materials
- Two-dimensional materials

## Abstract

Functionalizing the surfaces of transition metal dichalcogenide (TMD) nanosheets with noble metals is important for electrically contacting them to devices, as well as improving their catalytic and sensing capabilities. Solution-phase deposition provides a scalable approach to the creation of metal–TMD hybrid systems, but controlling such processes remains challenging. Here we elucidate the different pathways by which gold and silver deposit at room temperature onto colloidal 1T-WS2, 2H-WS2, 2H-MoSe2, 2H-WSe2, 1T′-MoTe2 and Td-WTe2 few-layer nanostructures to produce several distinct classes of 0D–2D and 2D–2D metal–TMD hybrids. Uniform gold nanoparticles form on all of the TMDs. By contrast, silver deposits as nanoparticles with a bimodal size distribution on the disulfides and diselenides, and as atomically thin layers on the ditellurides. The various sizes and morphologies of these surface-bound metal species arise from the relative strengths of the interfacial metal–chalcogen bonds during the reduction of Au3+ or Ag+ by the TMDs.

Access through your institution
Change institution
Buy or subscribe

## Access options

Subscribe to Journal

Get full journal access for 1 year

$169.00

only $14.08 per issue

Subscribe

All prices are NET prices.
VAT will be added later in the checkout.

Rent or Buy article

Get time limited or full article access on ReadCube.

from$8.99

Rent or Buy

All prices are NET prices.

Fig. 1: Reduction of Au3+ on TMD nanostructures.
Fig. 2: The influence of electronic structure and structural defects on the reduction of Au3+ on TMD nanostructures.
Fig. 3: Reduction of Ag+ on TMD nanostructures.
Fig. 4: Microscopic evidence of atomic Ag layers deposited on the 1T′-MoTe2 nanostructures.
Fig. 5: Spectroscopic investigation of Ag/1 T′-MoTe2 and Ag/WTe2.
Fig. 6: DFT calculations for noble metal–TMD systems.

## Data availability

All of the data that support the findings of this study are available within the Article and its Supplementary Information, and/or from the corresponding author on reasonable request.

## References

1. 1.

   Wang, Q. H., Kalantar-Zadeh, K., Kis, A., Coleman, J. N. & Strano, M. S. Electronics and optoelectronics of two-dimensional transition metal dichalcogenides. Nat. Nanotechnol. 7, 699–712 (2012).

   CAS PubMed Google Scholar

2. 2.

   Lv, R. et al. Transition metal dichalcogenides and beyond: synthesis, properties, and applications of single- and few-layer nanosheets. Acc. Chem. Res. 48, 56–64 (2015).

   CAS PubMed Google Scholar

3. 3.

   Jaramillo, T. F. et al. Identification of active edge sites for electrochemical H2 evolution from MoS2 nanocatalysts. Science 317, 100–102 (2007).

   CAS PubMed Google Scholar

4. 4.

   Ali, M. N. et al. Large, non-saturating magnetoresistance in WTe2. Nature 514, 205–208 (2014).

   CAS PubMed PubMed Central Google Scholar

5. 5.

   Gong, Y. et al. Vertical and in-plane heterostructures from WS2/MoS2 monolayers. Nat. Mater. 13, 1135–1142 (2014).

   CAS PubMed Google Scholar

6. 6.

   Voiry, D. et al. Covalent functionalization of monolayered transition metal dichalcogenides by phase engineering. Nat. Chem. 7, 45–49 (2014).

   PubMed Google Scholar

7. 7.

   Kang, Y. et al. Plasmonic hot electron induced structural phase transition in a MoS2 monolayer. Adv. Mater. 26, 6467–6471 (2014).

   CAS PubMed Google Scholar

8. 8.

   Chen, J. et al. Edge epitaxy of two-dimensional MoSe2 and MoS2 nanosheets on one-dimensional nanowires. J. Am. Chem. Soc. 139, 8653–8660 (2017).

   CAS PubMed Google Scholar

9. 9.

   Kang, D.-H. et al. An ultrahigh-performance photodetector based on a perovskite-transition-metal-dichalcogenide hybrid structure. Adv. Mater. 28, 7799–7806 (2016).

   CAS PubMed Google Scholar

10. 10.

    Chhowalla, M. et al. The chemistry of two-dimensional layered transition metal dichalcogenide nanosheets. Nat. Chem. 5, 263–275 (2013).

    PubMed Google Scholar

11. 11.

    Li, H. et al. Synergetic interaction between neighbouring platinum monomers in CO2 hydrogenation. Nat. Nanotechnol. 13, 411–417 (2018).

    CAS PubMed Google Scholar

12. 12.

    Huang, X. et al. Solution-phase epitaxial growth of noble metal nanostructures on dispersible single-layer molybdenum disulfide nanosheets. Nat. Commun. 4, 1444 (2013).

    PubMed Google Scholar

13. 13.

    Liu, Y. et al. Approaching the Schottky–Mott limit in van der Waals metal-semiconductor junctions. Nature 557, 696–700 (2018).

    CAS PubMed Google Scholar

14. 14.

    Popov, I., Seifert, G. & Tománek, D. Designing electrical contacts to MoS2 monolayers: a computational study. Phys. Rev. Lett. 108, 156802 (2012).

    PubMed Google Scholar

15. 15.

    Zhao, W. et al. Exciton–plasmon coupling and electromagnetically induced transparency in monolayer semiconductors hybridized with Ag nanoparticles. Adv. Mater. 28, 2709–2715 (2016).

    CAS PubMed Google Scholar

16. 16.

    Zheng, D. et al. Manipulating coherent plasmon–exciton interaction in a single silver nanorod on monolayer WSe2. Nano Lett. 17, 3809–3814 (2017).

    CAS PubMed Google Scholar

17. 17.

    Najmaei, S. et al. Plasmonic pumping of excitonic photoluminescence in hybrid MoS2–Au nanostructures. ACS Nano 8, 12682–12689 (2014).

    CAS PubMed Google Scholar

18. 18.

    Gong, C. et al. Metal contacts on physical vapor deposited monolayer MoS2. ACS Nano 7, 11350–11357 (2013).

    CAS PubMed Google Scholar

19. 19.

    Lei, S. et al. Surface functionalization of two-dimensional metal chalcogenides by lewis acid–base chemistry. Nat. Nanotechnol. 11, 465–471 (2016).

    CAS PubMed Google Scholar

20. 20.

    Son, D. et al. Colloidal synthesis of uniform-sized molybdenum disulfide nanosheets for wafer-scale flexible nonvolatile memory. Adv. Mater. 28, 9326–9332 (2016).

    CAS PubMed Google Scholar

21. 21.

    Mahler, B., Hoepfner, V., Liao, K. & Ozin, G. A. Colloidal synthesis of 1T-WS2 and 2H-WS2 nanosheets: applications for photocatalytic hydrogen evolution. J. Am. Chem. Soc. 136, 14121–14127 (2014).

    CAS PubMed Google Scholar

22. 22.

    Yoo, D., Kim, M., Jeong, S., Han, J. & Cheon, J. Chemical synthetic strategy for single-layer transition-metal chalcogenides. J. Am. Chem. Soc. 136, 14670–14673 (2014).

    CAS PubMed Google Scholar

23. 23.

    Jung, W. et al. Colloidal synthesis of single-layer MSe2 (M = Mo, W) nanosheets via anisotropic solution-phase growth approach. J. Am. Chem. Soc. 137, 7266–7269 (2015).

    CAS PubMed Google Scholar

24. 24.

    Sun, D., Feng, S., Terrones, M. & Schaak, R. E. Formation and interlayer decoupling of colloidal MoSe2 nanoflowers. Chem. Mater. 27, 3167–3175 (2015).

    CAS Google Scholar

25. 25.

    Sun, Y. et al. Low-temperature solution synthesis of few-layer 1T’-MoTe2 nanostructures exhibiting lattice compression. Angew. Chem. Int. Ed. 55, 2830–2834 (2016).

    CAS Google Scholar

26. 26.

    Sun, Y., Fujisawa, K., Terrones, M. & Schaak, R. E. Solution synthesis of few-layer WTe2 and MoxW1−xTe2 nanostructures. J. Mater. Chem. C 5, 11317–11323 (2017).

    CAS Google Scholar

27. 27.

    Sun, Y. et al. Low-temperature solution synthesis of transition metal dichalcogenide alloys with tunable optical properties. J. Am. Chem. Soc. 139, 11096–11105 (2017).

    CAS PubMed Google Scholar

28. 28.

    Kim, J., Byun, S., Smith, A. J., Yu, J. & Huang, J. Enhanced electrocatalytic properties of transition-metal dichalcogenides sheets by spontaneous gold nanoparticle decoration. J. Phys. Chem. Lett. 4, 1227–1232 (2013).

    CAS PubMed Google Scholar

29. 29.

    Yeh, Y.-T. et al. Light-emitting transition metal dichalcogenide monolayers under cellular digestion. Adv. Mater. 30, 1703321 (2018).

    Google Scholar

30. 30.

    Raza, F. et al. Structuring Pd nanoparticles on 2H-WS2 nanosheets induces excellent photocatalytic activity for cross-coupling reactions under visible light. J. Am. Chem. Soc. 139, 14767–14774 (2017).

    CAS PubMed Google Scholar

31. 31.

    Huo, Z., Tsung, C., Huang, W., Zhang, X. & Yang, P. Sub-two nanometer single crystal Au nanowires. Nano Lett. 8, 2041–2044 (2008).

    CAS PubMed Google Scholar

32. 32.

    Peng, S. et al. A facile synthesis of monodisperse Au nanoparticles and their catalysis of CO oxidation. Nano Res. 1, 229–234 (2008).

    CAS Google Scholar

33. 33.

    Choi, H. C., Shim, M., Bangsaruntip, S. & Dai, H. Spontaneous reduction of metal ions on the sidewalls of carbon nanotubes. J. Am. Chem. Soc. 124, 9058–9059 (2002).

    CAS PubMed Google Scholar

34. 34.

    Zhou, W. et al. Intrinsic structural defects in monolayer molybdenum disulfide. Nano Lett. 13, 2615–2622 (2013).

    CAS PubMed Google Scholar

35. 35.

    Sun, Y. et al. Defect-mediated selective hydrogenation of nitroarenes on nanostructured WS2. Chem. Sci. 10, 10310–10317 (2019).

    CAS Google Scholar

36. 36.

    Ulman, A. Formation and structure of self-assembled monolayers. Chem. Rev. 96, 1533–1554 (1996).

    CAS PubMed Google Scholar

37. 37.

    Laibinis, P. E. et al. Comparison of the structures and wetting properties of self-assembled monolayers of n-alkanethiols on the coinage metal surfaces, copper, silver, and gold. J. Am. Chem. Soc. 113, 7152–7167 (1991).

    CAS Google Scholar

38. 38.

    Hebb, M. H. Electrical conductivity of silver sulfide. J. Chem. Phys. 20, 185–190 (1952).

    CAS Google Scholar

39. 39.

    Elliott, S. R. A unified mechanism for metal photodissolution in amorphous chalcogenide materials. J. Non-Cryst. Solids 130, 85–97 (1991).

    CAS Google Scholar

40. 40.

    Hodges, J. M., Morse, J. R., Williams, M. E. & Schaak, R. E. Microscopic investigation of chemoselectivity in Ag–Pt–Fe3O4 heterotrimer formation: mechanistic insights and implications for controlling high-order hybrid nanoparticle morphology. J. Am. Chem. Soc. 137, 15493–15500 (2015).

    CAS PubMed Google Scholar

41. 41.

    Ridelman, Y. et al. Metallic nanobowls by galvanic replacement reaction on heterodimeric nanoparticles. Small 8, 654–660 (2012).

    CAS PubMed Google Scholar

42. 42.

    Hla, S. W., Prodan, A. & van Midden, H. J. P. Atomistic stress fluctuation at surfaces and edges of epitaxially grown silver nanorods. Nano Lett. 4, 1221–1224 (2004).

    CAS Google Scholar

43. 43.

    Milenov, T. I. et al. Preliminary studies of the Raman spectra of Ag2Te and Ag5Te3. Opt. Quant. Electron. 46, 573–580 (2014).

    CAS Google Scholar

44. 44.

    Gaarenstroom, S. W. & Winograd, N. Initial and final state effects in the ESCA spectra of cadmium and silver oxides. J. Chem. Phys. 67, 3500–3506 (1977).

    CAS Google Scholar

45. 45.

    Rodriguez, J. A. & Goodman, D. W. Surface science studies of the electronic and chemical properties of bimetallic systems. J. Phys. Chem. 95, 4196–4206 (1991).

    CAS Google Scholar

46. 46.

    Hu, P. et al. Electronic metal–support interactions in single-atom catalysts. Angew. Chem. Int. Ed. 53, 3418–3421 (2014).

    CAS Google Scholar

47. 47.

    Miller, J. T. et al. The effect of gold particle size on the Au–Au bond distance and ractivity toward oxygen in supported catalysts. J. Catal. 240, 222–234 (2006).

    CAS Google Scholar

48. 48.

    Wei, H. et al. Selective hydrogenation of acrolein on supported silver catalysts: a kinetic study of particle size effects. J. Catal. 298, 18–26 (2013).

    CAS Google Scholar

49. 49.

    van der Lee, A. & de Boer, J. L. Redetermination of the structure of hessite, Ag2Te-iii. Acta Cryst. C 49, 1444–1446 (1993).

    Google Scholar

50. 50.

    Dawson, W. & Bullett, D. Electronic structure and crystallography of MoTe2 and WTe2. J. Phys. C 20, 6159–6174 (1987).

    CAS Google Scholar

51. 51.

    Hla, S. W., Marinković, V. & Prodan, A. The growth of gold on (001) surfaces of α- and β-MoTe2. Surf. Sci. 356, 130–136 (1996).

    CAS Google Scholar

52. 52.

    Plieth, W. J. Electrochemical properties of small clusters of metal atoms and their role in the surface enhanced Raman scattering. J. Phys. Chem. 86, 3166–3170 (1982).

    CAS Google Scholar

53. 53.

    Tang, L. et al. Electrochemical stability of nanometer-scale Pt particles in acidic environments. J. Am. Chem. Soc. 132, 596–600 (2010).

    CAS PubMed Google Scholar

54. 54.

    Tauster, S. J., Fung, S. C., Baker, R. T. K. & Horsley, J. A. Strong interactions in supported-metal catalysts. Science 211, 1121–1125 (1981).

    CAS PubMed Google Scholar

55. 55.

    Wang, Y. et al. Van der Waals contacts between three-dimensional metals and two-dimensional semiconductors. Nature 568, 70–74 (2019).

    CAS PubMed Google Scholar

56. 56.

    Koch, C. T. Determination of Core Structure Periodicity and Point Defect Density along Dislocations. PhD thesis, Arizona State Univ. (2002).

57. 57.

    Rehr, J. J., Kas, J. J., Vila, F. D., Prange, M. P. & Jorissen, K. Parameter-free calculations of X-ray spectra with FEFF9. Phys. Chem. Chem. Phys. 12, 5503 (2010).

    CAS PubMed Google Scholar

58. 58.

    Perdew, J. P. et al. Restoring the density-gradient expansion for exchange in solids and surfaces. Phys. Rev. Lett. 100, 136406 (2008).

    PubMed Google Scholar

59. 59.

    Tran, F., Stelzl, J. & Blaha, P. Rungs 1 to 4 of DFT Jacob’s ladder: extensive test on the lattice constant, bulk modulus, and cohesive energy of solids. J. Chem. Phys. 144, 204120 (2016).

    PubMed Google Scholar

60. 60.

    Elsasser, C. et al. Relativistic effects on ground state properties of 4d and 5d transition metals. J. Phys. Condens. Matter 2, 4371–4394 (1990).

    CAS Google Scholar

61. 61.

    Granatier, J., Lazar, P., Otyepka, M. & Hobza, P. The nature of the binding of Au, Ag, and Pd to benzene, coronene, and graphene: from benchmark CCSD(T) calculations to plane-wave DFT calculations. J. Chem. Theory Comput. 7, 3743–3755 (2011).

    CAS PubMed PubMed Central Google Scholar

Download references

## Acknowledgements

Y.S. and R.E.S. were supported by the US National Science Foundation grant DMR-1607135 for the initial synthesis of the TMD nanostructures and grant CHE-1707830 for the studies involving deposition of Au and Ag. Y.W. and V.H.C. acknowledge the National Science Foundation Materials Innovation Platform Two-Dimensional Crystal Consortium under grant no. DMR-1539916. J.Y.C.C. and C.F.H. were supported by funds from Penn State University. Y.S., K.F. and M.T. acknowledge support from the Air Force Office of Scientific Research (AFOSR) grant FA9550-18-1-0072. J.T.M. was supported by the National Science Foundation under Cooperative Agreement no. EEC‐1647722. V.H.C. and M.T. also acknowledge the Center for 2-Dimensional and Layered Materials at the Pennsylvania State University. Electron microscopy and XPS were performed at the Electron Microscopy Facility at the Materials Characterization Lab of the Penn State Materials Research Institute. Use of APS is supported by the US Department of Energy, Office of Science, and Office of Basic Energy Sciences under contract no. DE-AC02-06CH11357. MRCAT operations (beamline 10-BM) are supported by the Department of Energy and the MRCAT member institutions. We thank J. Katsoudas and J. Wright for the assistance during XAS experiments at the 10-BM beamline at the APS at Argonne National Laboratory. We also thank J. Grey and K. Wang for assistance with TEM characterization and J. Shallenberger for XPS acquisition and analysis.

## Author information

### Affiliations

1. Department of Chemistry, The Pennsylvania State University, University Park, PA, USA

   Yifan Sun, Jamie Y. C. Chen, Cameron F. Holder, Vincent H. Crespi, Mauricio Terrones & Raymond E. Schaak

2. Materials Research Institute, The Pennsylvania State University, University Park, PA, USA

   Yifan Sun, Yuanxi Wang, Kazunori Fujisawa, Vincent H. Crespi, Mauricio Terrones & Raymond E. Schaak

3. Center for 2-Dimensional and Layered Materials, The Pennsylvania State University, University Park, PA, USA

   Yifan Sun, Yuanxi Wang, Kazunori Fujisawa, Vincent H. Crespi & Mauricio Terrones

4. Department of Physics, The Pennsylvania State University, University Park, PA, USA

   Yuanxi Wang, Kazunori Fujisawa, Vincent H. Crespi & Mauricio Terrones

5. 2-Dimensional Crystal Consortium, The Pennsylvania State University, University Park, PA, USA

   Yuanxi Wang & Vincent H. Crespi

6. Charles D. Davidson School of Chemical Engineering, Purdue University, West Lafayette, IN, USA

   Jeffery T. Miller

7. Department of Materials Science and Engineering, The Pennsylvania State University, University Park, PA, USA

   Vincent H. Crespi & Mauricio Terrones

8. Department of Chemical Engineering, The Pennsylvania State University, University Park, PA, USA

   Raymond E. Schaak

Authors

1. Yifan Sun
   View author publications

   You can also search for this author in PubMed Google Scholar

2. Yuanxi Wang
   View author publications

   You can also search for this author in PubMed Google Scholar

3. Jamie Y. C. Chen
   View author publications

   You can also search for this author in PubMed Google Scholar

4. Kazunori Fujisawa
   View author publications

   You can also search for this author in PubMed Google Scholar

5. Cameron F. Holder
   View author publications

   You can also search for this author in PubMed Google Scholar

6. Jeffery T. Miller
   View author publications

   You can also search for this author in PubMed Google Scholar

7. Vincent H. Crespi
   View author publications

   You can also search for this author in PubMed Google Scholar

8. Mauricio Terrones
   View author publications

   You can also search for this author in PubMed Google Scholar

9. Raymond E. Schaak
   View author publications

   You can also search for this author in PubMed Google Scholar

### Contributions

Y.S. carried out all the synthetic work and characterization by XRD, TEM, HAADF-STEM, STEM-EDS and Raman. Y.W. and V.H.C. performed the DFT calculations. J.Y.C.C., C.F.H. and Y.S. conducted the XAS measurements. J.Y.C.C. and J.T.M. analysed EXAFS and XANES data. C.F.H. also carried out XPS acquisition and analysis for part of the samples. K.F. carried out the high-resolution ADF-STEM imaging and simulation. M.T. and R.E.S. conceived and directed the project. Y.S., Y.W., J.Y.C.C., V.H.C., M.T. and R.E.S. prepared the manuscript.

### Corresponding authors

Correspondence to Vincent H. Crespi or Mauricio Terrones or Raymond E. Schaak.

## Ethics declarations

### Competing interests

The authors declare no competing interests.

## Additional information

Publisher’s note Springer Nature remains neutral with regard to jurisdictional claims in published maps and institutional affiliations.

## Supplementary information

Additional experimental and calculation details, Supplementary Tables 1–5, Figs. 1–34 and refs. 1–25.

## Rights and permissions

Reprints and Permissions

## About this article

### Cite this article

Sun, Y., Wang, Y., Chen, J.Y.C. et al. Interface-mediated noble metal deposition on transition metal dichalcogenide nanostructures. Nat. Chem. 12, 284–293 (2020). https://doi.org/10.1038/s41557-020-0418-3

Download citation

- Received: 09 September 2018

- Accepted: 06 January 2020

- Published: 24 February 2020

- Issue Date: March 2020

- DOI: https://doi.org/10.1038/s41557-020-0418-3

## Further reading

- ### Fabrication of noble metal nanoparticles decorated on one dimensional hierarchical polypyrrole@MoS2 microtubes

  - Yang Ling
  - , Tiantian Cao
  - , Libin Liu
  - , Jingli Xu
  - , Jing Zheng
  - , Jiaxing Li
  - & Min Zhang

  Journal of Materials Chemistry B (2020)

- ### Boosting electrochemical oxygen evolution over yolk-shell structured O–MoS2 nanoreactors with sulfur vacancy and decorated Pt nanoparticles

  - Feilong Gong
  - , Sheng Ye
  - , Mengmeng Liu
  - , Jiangwei Zhang
  - , Lihua Gong
  - , Guang Zeng
  - , Erchao Meng
  - , Panpan Su
  - , Kefeng Xie
  - , Yonghui Zhang
  - & Jian Liu

  Nano Energy (2020)

- ### Surface coordination chemistry of graphene: Understanding the coordination of single transition metal atoms

  - Daniel Grasseschi
  - , Walner Costa Silva
  - , Ronald de Souza Paiva
  - , Leon Diez Starke
  - & Arley Sena do Nascimento

  Coordination Chemistry Reviews (2020)

- ### Noble metal and Fe3O4Co-functionalizedco-functionalized hierarchical polyaniline@MoS2 microtubes

  - Zimeng Li
  - , Min Zhang
  - , Libin Liu
  - , Jing Zheng
  - , Hamed Alsulami
  - , Marwan Amin Kutbi
  - & Jingli Xu

  Colloids and Surfaces A: Physicochemical and Engineering Aspects (2020)

- ### Holey Pt Nanosheets on NiFe-Hydroxide Laminates: Synergistically Enhanced Electrocatalytic 2D Interface toward Hydrogen Evolution Reaction

  - Sun Woo Jang
  - , Soumen Dutta
  - , Amit Kumar
  - , Yu-Rim Hong
  - , Hanuel Kang
  - , Shinbi Lee
  - , Sunmin Ryu
  - , Wonyong Choi
  - & In Su Lee

  ACS Nano (2020)

Access through your institution
Change institution
Buy or subscribe

Sign up for the Nature Briefing newsletter — what matters in science, free to your inbox daily.

Email address
I agree my information will be processed in accordance with the Nature and Springer Nature Limited Privacy Policy.
Get the most important science stories of the day, free in your inbox. Sign up for Nature Briefing